
This is a library where you can download files
It will be updated irregularly in the future
usage method：
import download_ file as a
path=a.select_file()
a. download (URL, path)
=====Version update log======
Version 0.1 updates the downloader
Version 0.2 updates the file selector
=======================